@@ -332,11 +332,10 @@ srctl_list_collect(sr_conn_ctx_t *conn, const struct ly_ctx *ly_ctx, struct list
 {
     struct list_item *cur_item;
     const struct lys_module *ly_mod;
-    const struct lysp_feature *f;
     char *owner, *group;
-    const char *str;
+    const char *str, *feat;
     int ret = SR_ERR_OK, enabled;
-    uint32_t idx = 0, idx2;
+    uint32_t idx = 0;
     LY_ARRAY_COUNT_TYPE u;
 
     while ((ly_mod = ly_ctx_get_module_iter(ly_ctx, &idx))) {
@@ -358,32 +357,26 @@ srctl_list_collect(sr_conn_ctx_t *conn, const struct ly_ctx *ly_ctx, struct list
         cur_item->name = strdup(ly_mod->name);
         cur_item->revision = ly_mod->revision ? strdup(ly_mod->revision) : strdup("");
 
+        /* replay-support */
+        enabled = 0;
         if (ly_mod->implemented) {
-            /* replay-support */
             ret = sr_get_module_replay_support(conn, ly_mod->name, NULL, &enabled);
             if (ret != SR_ERR_OK) {
-                return ret;
+                goto cleanup;
             }
-            cur_item->replay = enabled;
-        } else {
-            /* replay-support */
-            cur_item->replay = 0;
         }
+        cur_item->replay = enabled;
 
-        /* enabled features */
-        f = NULL;
-        idx2 = 0;
-        while ((f = lysp_feature_next(f, ly_mod->parsed, &idx2))) {
-            if (!(f->flags & LYS_FENABLED)) {
-                /* disabled, skip */
-                continue;
+        /* collect enabled features */
+        if (ly_mod->implemented) {
+            LY_ARRAY_FOR(ly_mod->compiled->features, u) {
+                feat = ly_mod->compiled->features[u];
+                cur_item->features = realloc(cur_item->features, strlen(cur_item->features) + strlen(feat) + 2);
+                if (cur_item->features[0]) {
+                    strcat(cur_item->features, " ");
+                }
+                strcat(cur_item->features, feat);
             }
-
-            cur_item->features = realloc(cur_item->features, strlen(cur_item->features) + strlen(f->name) + 2);
-            if (cur_item->features[0]) {
-                strcat(cur_item->features, " ");
-            }
-            strcat(cur_item->features, f->name);
         }
 
         if (ly_mod->implemented) {
@@ -393,11 +386,11 @@ srctl_list_collect(sr_conn_ctx_t *conn, const struct ly_ctx *ly_ctx, struct list
             /* owner and permissions */
             ret = sr_get_module_ds_access(conn, cur_item->name, SR_DS_STARTUP, &owner, &group, &cur_item->start_perms);
             if (ret != SR_ERR_OK) {
-                return ret;
+                goto cleanup;
             }
             ret = sr_get_module_ds_access(conn, cur_item->name, SR_DS_RUNNING, NULL, NULL, &cur_item->run_perms);
             if (ret != SR_ERR_OK) {
-                return ret;
+                goto cleanup;
             }
             cur_item->owner = malloc(strlen(owner) + 1 + strlen(group) + 1);
             sprintf(cur_item->owner, "%s:%s", owner, group);
@@ -414,7 +407,7 @@ srctl_list_collect(sr_conn_ctx_t *conn, const struct ly_ctx *ly_ctx, struct list
         }
 
         /* new submodules */
-        LY_ARRAY_FOR(ly_mod->parsed->includes, u) {
+        LY_ARRAY_FOR(ly_mod->submodules, u) {
             *list = realloc(*list, (*list_count + 1) * sizeof **list);
             cur_item = &(*list)[*list_count];
             ++(*list_count);
@@ -427,16 +420,18 @@ srctl_list_collect(sr_conn_ctx_t *conn, const struct ly_ctx *ly_ctx, struct list
             cur_item->main_mod = strdup(ly_mod->name);
 
             /* name and revision */
-            if (asprintf(&cur_item->name, " %s", ly_mod->parsed->includes[u].submodule->name) == -1) {
+            if (asprintf(&cur_item->name, " %s", ly_mod->submodules[u].name) == -1) {
                 error_print(0, "Memory allocation failed");
-                return SR_ERR_NO_MEMORY;
+                ret = SR_ERR_NO_MEMORY;
+                goto cleanup;
             }
-            str = ly_mod->parsed->includes[u].submodule->revs ? ly_mod->parsed->includes[u].submodule->revs[0].date : NULL;
+            str = ly_mod->submodules[u].revision;
             cur_item->revision = str ? strdup(str) : strdup("");
         }
     }
 
-    return SR_ERR_OK;
+cleanup:
+    return ret;
 }
 
 static int
