@@ -28,43 +28,25 @@
 #include <libyang/plugins_types.h>
 
 #include "common.h"
+#include "context_change.h"
 #include "log.h"
 #include "sysrepo.h"
 
-#define SR_CHECK_LY_GOTO(cond, ly_ctx, err_info, go) if (cond) { sr_errinfo_new_ly(&(err_info), ly_ctx, NULL); goto go; }
-#define SR_CHECK_LY_RET(cond, ly_ctx, err_info) if (cond) { sr_errinfo_new_ly(&(err_info), ly_ctx, NULL); return err_info; }
-
 /**
  * @brief Log the error(s) from a libyang context and add them into an error info structure.
  *
  * @param[in,out] err_info Existing error info.
  * @param[in] ly_ctx libyang context to use.
- * @param[in] data Optional data tree to look for another extension context that may have the error.
  * @param[in] err_code Error code to use.
  */
 static void
-sr_errinfo_new_ly(sr_error_info_t **err_info, const struct ly_ctx *ly_ctx, const struct lyd_node *data,
-        sr_error_t err_code)
+sr_errinfo_new_ly(sr_error_info_t **err_info, const struct ly_ctx *ly_ctx, sr_error_t err_code)
 {
     const struct ly_err_item *e = NULL;
-    const struct lyd_node *node;
 
     if (ly_ctx) {
         e = ly_err_first(ly_ctx);
     }
-    if (!e && data) {
-        if (ly_ctx != LYD_CTX(data)) {
-            e = ly_err_first(LYD_CTX(data));
-        } else {
-            LYD_TREE_DFS_BEGIN(data, node) {
-                if (node->flags & LYD_EXT) {
-                    e = ly_err_first(LYD_CTX(node));
-                    break;
-                }
-                LYD_TREE_DFS_END(data, node);
-            }
-        }
-    }
 
     if (!e) {
         /* this function is called only when an error is expected, but it is still possible there
@@ -95,54 +77,8 @@ sr_errinfo_new_ly(sr_error_info_t **err_info, const struct ly_ctx *ly_ctx, const
     }
 }
 
-/**
- * @brief Ext data callback for a connection context to provide schema mount data.
- */
-static LY_ERR
-sr_ly_ext_data_clb(const struct lysc_ext_instance *ext, void *user_data, void **ext_data, ly_bool *ext_data_free)
-{
-    sr_error_info_t *err_info = NULL;
-    sr_conn_ctx_t *conn = user_data;
-    struct lyd_node *ext_data_dup;
-    LY_ERR r;
-
-    if (strcmp(ext->def->module->name, "ietf-yang-schema-mount") || strcmp(ext->def->name, "mount-point")) {
-        return LY_EINVAL;
-    }
-
-    /* LY EXT DATA READ LOCK */
-    if ((err_info = sr_rwlock(&conn->ly_ext_data_lock, SR_CONN_EXT_DATA_LOCK_TIMEOUT, SR_LOCK_READ, conn->cid,
-            __func__, NULL, NULL))) {
-        sr_errinfo_free(&err_info);
-        return LY_ESYS;
-    }
-
-    if (!conn->ly_ext_data) {
-        sr_errinfo_new(&err_info, SR_ERR_NOT_FOUND,
-                "No \"ietf-yang-schema-mount\" operational data set needed for parsing mounted data.");
-        sr_errinfo_free(&err_info);
-        r = LY_ENOTFOUND;
-    } else {
-        /* create LY ext data duplicate */
-        r = lyd_dup_siblings(conn->ly_ext_data, NULL, LYD_DUP_RECURSIVE | LYD_DUP_WITH_FLAGS, &ext_data_dup);
-    }
-
-    /* LY EXT DATA UNLOCK */
-    sr_rwunlock(&conn->ly_ext_data_lock, SR_CONN_EXT_DATA_LOCK_TIMEOUT, SR_LOCK_READ, conn->cid, __func__);
-
-    if (r) {
-        return r;
-    }
-
-    /* return a duplicate of ext data */
-    *ext_data = ext_data_dup;
-    *ext_data_free = 1;
-
-    return LY_SUCCESS;
-}
-
 sr_error_info_t *
-sr_ly_ctx_init(sr_conn_ctx_t *conn, struct ly_ctx **ly_ctx)
+sr_ly_ctx_new(struct ly_ctx **ly_ctx)
 {
     sr_error_info_t *err_info = NULL;
     char *yang_dir;
@@ -153,8 +89,11 @@ sr_ly_ctx_init(sr_conn_ctx_t *conn, struct ly_ctx **ly_ctx)
     LY_ERR lyrc;
 
     /* context options */
-    ctx_opts = LY_CTX_NO_YANGLIBRARY | LY_CTX_DISABLE_SEARCHDIR_CWD | LY_CTX_REF_IMPLEMENTED | LY_CTX_EXPLICIT_COMPILE;
-    if (conn && (conn->opts & SR_CONN_CTX_SET_PRIV_PARSED)) {
+    ctx_opts = LY_CTX_NO_YANGLIBRARY | LY_CTX_DISABLE_SEARCHDIR_CWD | LY_CTX_REF_IMPLEMENTED |
+            LY_CTX_EXPLICIT_COMPILE | LY_CTX_STATIC_PLUGINS_ONLY | LY_CTX_LYB_HASHES;
+
+    /* add the configured options */
+    if (ATOMIC_LOAD_RELAXED(sr_yang_ctx.sr_opts) & SR_CTX_SET_PRIV_PARSED) {
         ctx_opts |= LY_CTX_SET_PRIV_PARSED;
     }
 
@@ -173,41 +112,38 @@ sr_ly_ctx_init(sr_conn_ctx_t *conn, struct ly_ctx **ly_ctx)
 
     /* load just the internal datastores modules and the "sysrepo" module */
     if (lys_parse_mem(*ly_ctx, ietf_datastores_yang, LYS_IN_YANG, NULL)) {
-        sr_errinfo_new_ly(&err_info, *ly_ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *ly_ctx, SR_ERR_LY);
         goto cleanup;
     }
     if (lys_parse_mem(*ly_ctx, sysrepo_yang, LYS_IN_YANG, NULL)) {
-        sr_errinfo_new_ly(&err_info, *ly_ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *ly_ctx, SR_ERR_LY);
         goto cleanup;
     }
     if (lys_parse_mem(*ly_ctx, ietf_netconf_acm_yang, LYS_IN_YANG, NULL)) {
-        sr_errinfo_new_ly(&err_info, *ly_ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *ly_ctx, SR_ERR_LY);
         goto cleanup;
     }
 
     if (ly_in_new_memory(ietf_factory_default_yang, &in)) {
-        sr_errinfo_new_ly(&err_info, NULL, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, NULL, SR_ERR_LY);
         goto cleanup;
     }
     if (lys_parse(*ly_ctx, in, LYS_IN_YANG, factory_default_features, NULL)) {
-        sr_errinfo_new_ly(&err_info, *ly_ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *ly_ctx, SR_ERR_LY);
         goto cleanup;
     }
     if (lys_parse_mem(*ly_ctx, sysrepo_factory_default_yang, LYS_IN_YANG, NULL)) {
-        sr_errinfo_new_ly(&err_info, *ly_ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *ly_ctx, SR_ERR_LY);
         goto cleanup;
     }
 
-    /* compile */
-    if (ly_ctx_compile(*ly_ctx)) {
-        sr_errinfo_new_ly(&err_info, *ly_ctx, NULL, SR_ERR_LY);
+    /* compile the final context */
+    if ((err_info = sr_ly_ctx_compile(*ly_ctx))) {
         goto cleanup;
     }
 
-    if (conn) {
-        /* set the ext callback */
-        ly_ctx_set_ext_data_clb(*ly_ctx, sr_ly_ext_data_clb, conn);
-    }
+    /* set the ext callback */
+    ly_ctx_set_ext_data_clb(*ly_ctx, sr_ly_ext_data_clb, NULL);
 
 cleanup:
     if (err_info) {
@@ -242,7 +178,7 @@ sr_lys_parse(struct ly_ctx *ctx, const char *data, const char *path, LYS_INFORMA
     }
 
     if (lys_parse(ctx, in, format, features, ly_mod)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -261,7 +197,7 @@ sr_lys_set_implemented(struct lys_module *mod, const char **features)
     ly_temp_log_options(&temp_lo);
 
     if (lys_set_implemented(mod, features)) {
-        sr_errinfo_new_ly(&err_info, mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -288,7 +224,7 @@ sr_lys_print(const char *path, const struct lys_module *mod, const struct lysp_s
         lyrc = lys_print_module(out, mod, LYS_OUT_YANG, 0, 0);
     }
     if (lyrc) {
-        sr_errinfo_new_ly(&err_info, submod ? submod->mod->ctx : mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, submod ? submod->mod->ctx : mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -307,7 +243,7 @@ sr_ly_ctx_get_yanglib_data(const struct ly_ctx *ctx, struct lyd_node **data, uin
     ly_temp_log_options(&temp_lo);
 
     if (ly_ctx_get_yanglib_data(ctx, data, "0x%08x", content_id)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -327,7 +263,7 @@ sr_ly_ctx_load_module(struct ly_ctx *ctx, const char *name, const char *revision
     ly_temp_log_options(&temp_lo);
 
     if (!(mod = ly_ctx_load_module(ctx, name, revision, features))) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -346,7 +282,7 @@ sr_ly_ctx_compile(struct ly_ctx *ctx)
     ly_temp_log_options(&temp_lo);
 
     if (ly_ctx_compile(ctx)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -372,7 +308,7 @@ sr_lys_find_path(const struct ly_ctx *ctx, const char *path, int *valid, const s
         if (valid) {
             *valid = 0;
         } else {
-            sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+            sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         }
         goto cleanup;
     }
@@ -390,9 +326,13 @@ sr_error_info_t *
 sr_lys_find_xpath(const struct ly_ctx *ctx, const char *xpath, uint32_t options, int *valid, struct ly_set **set)
 {
     sr_error_info_t *err_info = NULL;
-    uint32_t temp_lo = LY_LOSTORE;
+    uint32_t temp_lo = LY_LOSTORE, *prev_lo;
 
-    ly_temp_log_options(&temp_lo);
+    prev_lo = ly_temp_log_options(&temp_lo);
+    if (prev_lo) {
+        /* nested call, keep the previous lo */
+        ly_temp_log_options(prev_lo);
+    }
 
     if (valid) {
         *valid = 1;
@@ -402,13 +342,15 @@ sr_lys_find_xpath(const struct ly_ctx *ctx, const char *xpath, uint32_t options,
         if (valid) {
             *valid = 0;
         } else {
-            sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+            sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         }
         goto cleanup;
     }
 
 cleanup:
-    ly_temp_log_options(NULL);
+    if (!prev_lo) {
+        ly_temp_log_options(NULL);
+    }
     return err_info;
 }
 
@@ -434,7 +376,7 @@ sr_lys_find_xpath_atoms(const struct ly_ctx *ctx, const char *xpath, uint32_t op
             /* free any errors which were generated */
             ly_err_clean((struct ly_ctx *) ctx, NULL);
         } else {
-            sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+            sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         }
         goto cleanup;
     }
@@ -454,7 +396,7 @@ sr_lys_find_expr_atoms(const struct lysc_node *ctx_node, const struct lys_module
     ly_temp_log_options(&temp_lo);
 
     if (lys_find_expr_atoms(ctx_node, cur_mod, exp, prefixes, options, set)) {
-        sr_errinfo_new_ly(&err_info, ctx_node->module->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx_node->module->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -468,10 +410,14 @@ sr_lyd_parse_data(const struct ly_ctx *ctx, const char *data, const char *data_p
         uint32_t parse_options, uint32_t validation_options, struct lyd_node **tree)
 {
     sr_error_info_t *err_info = NULL;
-    uint32_t temp_lo = LY_LOSTORE;
+    uint32_t temp_lo = LY_LOSTORE, *prev_lo;
     LY_ERR lyrc = LY_SUCCESS;
 
-    ly_temp_log_options(&temp_lo);
+    prev_lo = ly_temp_log_options(&temp_lo);
+    if (prev_lo) {
+        /* nested call, keep the previous lo */
+        ly_temp_log_options(prev_lo);
+    }
 
     *tree = NULL;
 
@@ -482,8 +428,8 @@ sr_lyd_parse_data(const struct ly_ctx *ctx, const char *data, const char *data_p
     }
 
     /* empty data are fine */
-    if (lyrc && (lyrc != LY_EINVAL)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+    if (lyrc && ((lyrc != LY_EINVAL) || strcmp(ly_last_logmsg(), "Empty input file."))) {
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -495,7 +441,9 @@ cleanup:
         lyd_free_siblings(*tree);
         *tree = NULL;
     }
-    ly_temp_log_options(NULL);
+    if (!prev_lo) {
+        ly_temp_log_options(NULL);
+    }
     return err_info;
 }
 
@@ -514,8 +462,8 @@ sr_lyd_parse_op(const struct ly_ctx *ctx, const char *data, LYD_FORMAT format, e
         goto cleanup;
     }
 
-    if (lyd_parse_op(ctx, NULL, in, format, data_type, tree, NULL)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+    if (lyd_parse_op(ctx, NULL, in, format, data_type, LYD_PARSE_STRICT, tree, NULL)) {
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -543,7 +491,7 @@ sr_lyd_print_data(const struct lyd_node *data, LYD_FORMAT format, uint32_t print
 
     if (lyd_print_all(out, data, format, print_options)) {
         if (data) {
-            sr_errinfo_new_ly(&err_info, LYD_CTX(data), NULL, SR_ERR_LY);
+            sr_errinfo_new_ly(&err_info, LYD_CTX(data), SR_ERR_LY);
         } else {
             SR_ERRINFO_INT(&err_info);
         }
@@ -569,7 +517,7 @@ sr_lyd_validate_all(struct lyd_node **data, const struct ly_ctx *ctx, uint32_t o
     ly_temp_log_options(&temp_lo);
 
     if (lyd_validate_all(data, ctx, options, NULL)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_VALIDATION_FAILED);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_VALIDATION_FAILED);
         goto cleanup;
     }
 
@@ -582,17 +530,23 @@ sr_error_info_t *
 sr_lyd_validate_module(struct lyd_node **data, const struct lys_module *mod, uint32_t options, struct lyd_node **diff)
 {
     sr_error_info_t *err_info = NULL;
-    uint32_t temp_lo = LY_LOSTORE;
+    uint32_t temp_lo = LY_LOSTORE, *prev_lo;
 
-    ly_temp_log_options(&temp_lo);
+    prev_lo = ly_temp_log_options(&temp_lo);
+    if (prev_lo) {
+        /* nested call, keep the previous lo */
+        ly_temp_log_options(prev_lo);
+    }
 
     if (lyd_validate_module(data, mod, options, diff)) {
-        sr_errinfo_new_ly(&err_info, mod->ctx, NULL, SR_ERR_VALIDATION_FAILED);
+        sr_errinfo_new_ly(&err_info, mod->ctx, SR_ERR_VALIDATION_FAILED);
         goto cleanup;
     }
 
 cleanup:
-    ly_temp_log_options(NULL);
+    if (!prev_lo) {
+        ly_temp_log_options(NULL);
+    }
     return err_info;
 }
 
@@ -609,7 +563,7 @@ sr_lyd_validate_module_final(struct lyd_node *data, const struct lys_module *mod
     ly_err_clean(mod->ctx, NULL);
 
     if (lyd_validate_module_final(data, mod, options)) {
-        sr_errinfo_new_ly(&err_info, mod->ctx, data, SR_ERR_VALIDATION_FAILED);
+        sr_errinfo_new_ly(&err_info, mod->ctx, SR_ERR_VALIDATION_FAILED);
         goto cleanup;
     }
 
@@ -636,7 +590,7 @@ sr_lyd_validate_op(struct lyd_node *op, const struct lyd_node *oper_data, enum l
     ly_err_clean((struct ly_ctx *)LYD_CTX(op), NULL);
 
     if (lyd_validate_op(op, oper_data, op_type, NULL)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(op), op, SR_ERR_VALIDATION_FAILED);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(op), SR_ERR_VALIDATION_FAILED);
         goto cleanup;
     }
 
@@ -659,9 +613,9 @@ sr_lyd_new_path(struct lyd_node *parent, const struct ly_ctx *ctx, const char *p
 
     ly_temp_log_options(&temp_lo);
 
-    if (lyd_new_path2(parent, ctx, path, value, value ? strlen(value) : 0, LYD_ANYDATA_STRING, options, new_parent,
+    if (lyd_new_path2(parent, ctx, path, value, value ? strlen(value) * 8 : 0, LYD_ANYDATA_STRING, options, new_parent,
             new_node)) {
-        sr_errinfo_new_ly(&err_info, ctx ? ctx : LYD_CTX(parent), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx ? ctx : LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -679,7 +633,7 @@ sr_lyd_new_term(struct lyd_node *parent, const struct lys_module *mod, const cha
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_term(parent, mod, name, value, 0, NULL)) {
-        sr_errinfo_new_ly(&err_info, parent ? LYD_CTX(parent) : mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, parent ? LYD_CTX(parent) : mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -698,7 +652,7 @@ sr_lyd_new_term2(struct lyd_node *parent, const struct lys_module *mod, const ch
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_term(parent, mod, name, value, 0, node)) {
-        sr_errinfo_new_ly(&err_info, parent ? LYD_CTX(parent) : mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, parent ? LYD_CTX(parent) : mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -715,8 +669,8 @@ sr_lyd_new_list(struct lyd_node *parent, const char *name, const char *key_value
 
     ly_temp_log_options(&temp_lo);
 
-    if (lyd_new_list3(parent, NULL, name, key_value ? &key_value : NULL, NULL, 0, node)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), NULL, SR_ERR_LY);
+    if (lyd_new_list3(parent, NULL, name, key_value ? (const void **)&key_value : NULL, NULL, 0, node)) {
+        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -734,7 +688,7 @@ sr_lyd_new_inner(struct lyd_node *parent, const struct lys_module *mod, const ch
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_inner(parent, mod, name, 0, node)) {
-        sr_errinfo_new_ly(&err_info, parent ? LYD_CTX(parent) : mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, parent ? LYD_CTX(parent) : mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -752,7 +706,7 @@ sr_lyd_new_any(struct lyd_node *parent, const char *name, void *value, LYD_ANYDA
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_any(parent, NULL, name, value, value_type, LYD_NEW_ANY_USE_VALUE, NULL)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -771,7 +725,7 @@ sr_lyd_new_opaq(const struct ly_ctx *ctx, const char *name, const char *value, c
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_opaq(NULL, ctx, name, value, prefix, module_name, node)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -789,7 +743,7 @@ sr_lyd_new_meta(struct lyd_node *parent, const struct lys_module *mod, const cha
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_meta(NULL, parent, mod, name, value, 0, NULL)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -809,7 +763,7 @@ sr_lyd_new_meta2(const struct ly_ctx *ctx, struct lyd_node *parent, const struct
 
     lyrc = lyd_new_meta2(ctx, parent, 0, attr, meta);
     if (lyrc && (lyrc != LY_ENOT)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -830,7 +784,7 @@ sr_lyd_dup_meta_single(const struct lyd_meta *meta, struct lyd_node *parent)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_dup_meta_single(meta, parent, NULL)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -851,7 +805,7 @@ sr_lyd_new_attr(struct lyd_node *parent, const char *mod_name, const char *name,
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_attr(parent, mod_name, name, value, NULL)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -869,7 +823,7 @@ sr_lyd_new_attr2(struct lyd_node *parent, const char *mod_ns, const char *name,
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_attr2(parent, mod_ns, name, value, NULL)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -887,7 +841,7 @@ sr_lyd_new_implicit_all(struct lyd_node **tree, const struct ly_ctx *ctx, uint32
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_implicit_all(tree, ctx, options, NULL)) {
-        sr_errinfo_new_ly(&err_info, *tree ? LYD_CTX(*tree) : ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *tree ? LYD_CTX(*tree) : ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -905,7 +859,7 @@ sr_lyd_new_implicit_module(struct lyd_node **data, const struct lys_module *mod,
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_implicit_module(data, mod, options, diff)) {
-        sr_errinfo_new_ly(&err_info, mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -923,7 +877,7 @@ sr_lyd_new_implicit_tree(struct lyd_node *tree, uint32_t options)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_new_implicit_tree(tree, options, NULL)) {
-        sr_errinfo_new_ly(&err_info, tree ? LYD_CTX(tree) : NULL, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, tree ? LYD_CTX(tree) : NULL, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -948,7 +902,7 @@ sr_lyd_dup(const struct lyd_node *node, struct lyd_node *parent, uint32_t option
     }
 
     if (lyrc) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(node), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(node), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -958,16 +912,15 @@ cleanup:
 }
 
 sr_error_info_t *
-sr_lyd_dup_siblings_to_ctx(const struct lyd_node *sibling, const struct ly_ctx *trg_ctx, uint32_t options,
-        struct lyd_node **dup)
+sr_lyd_dup_single_to_ctx(const struct lyd_node *node, const struct ly_ctx *trg_ctx, uint32_t options, struct lyd_node **dup)
 {
     sr_error_info_t *err_info = NULL;
     uint32_t temp_lo = LY_LOSTORE;
 
     ly_temp_log_options(&temp_lo);
 
-    if (lyd_dup_siblings_to_ctx(sibling, trg_ctx, NULL, options, dup)) {
-        sr_errinfo_new_ly(&err_info, trg_ctx, NULL, SR_ERR_LY);
+    if (lyd_dup_single_to_ctx(node, trg_ctx, NULL, options, dup)) {
+        sr_errinfo_new_ly(&err_info, trg_ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1023,7 +976,7 @@ sr_lyd_merge(struct lyd_node **target, const struct lyd_node *source, int siblin
         lyrc = lyd_merge_tree(target, source, options);
     }
     if (lyrc) {
-        sr_errinfo_new_ly(&err_info, *target ? LYD_CTX(*target) : LYD_CTX(source), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *target ? LYD_CTX(*target) : LYD_CTX(source), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1037,10 +990,14 @@ sr_lyd_merge_module(struct lyd_node **target, const struct lyd_node *source, con
         lyd_merge_cb merge_cb, void *cb_data, uint32_t options)
 {
     sr_error_info_t *err_info = NULL;
-    uint32_t temp_lo = LY_LOSTORE;
+    uint32_t temp_lo = LY_LOSTORE, *prev_lo;
     const struct ly_ctx *ly_ctx;
 
-    ly_temp_log_options(&temp_lo);
+    prev_lo = ly_temp_log_options(&temp_lo);
+    if (prev_lo) {
+        /* nested call, keep the previous lo */
+        ly_temp_log_options(prev_lo);
+    }
 
     if (mod) {
         ly_ctx = mod->ctx;
@@ -1051,12 +1008,14 @@ sr_lyd_merge_module(struct lyd_node **target, const struct lyd_node *source, con
     }
 
     if (lyd_merge_module(target, source, mod, merge_cb, cb_data, options)) {
-        sr_errinfo_new_ly(&err_info, ly_ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ly_ctx, SR_ERR_LY);
         goto cleanup;
     }
 
 cleanup:
-    ly_temp_log_options(NULL);
+    if (!prev_lo) {
+        ly_temp_log_options(NULL);
+    }
     return err_info;
 }
 
@@ -1064,22 +1023,28 @@ sr_error_info_t *
 sr_lyd_find_xpath(const struct lyd_node *tree, const char *xpath, struct ly_set **set)
 {
     sr_error_info_t *err_info = NULL;
-    uint32_t temp_lo = LY_LOSTORE;
+    uint32_t temp_lo = LY_LOSTORE, *prev_lo;
 
     if (!tree) {
         /* return empty set */
         return sr_ly_set_new(set);
     }
 
-    ly_temp_log_options(&temp_lo);
+    prev_lo = ly_temp_log_options(&temp_lo);
+    if (prev_lo) {
+        /* nested call, keep the previous lo */
+        ly_temp_log_options(prev_lo);
+    }
 
     if (lyd_find_xpath(tree, xpath, set)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(tree), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(tree), SR_ERR_LY);
         goto cleanup;
     }
 
 cleanup:
-    ly_temp_log_options(NULL);
+    if (!prev_lo) {
+        ly_temp_log_options(NULL);
+    }
     return err_info;
 }
 
@@ -1087,11 +1052,15 @@ sr_error_info_t *
 sr_lyd_find_path(const struct lyd_node *tree, const char *path, int with_incomplete, struct lyd_node **match)
 {
     sr_error_info_t *err_info = NULL;
-    uint32_t temp_lo = LY_LOSTORE;
+    uint32_t temp_lo = LY_LOSTORE, *prev_lo;
     LY_ERR lyrc;
     const struct ly_ctx *ctx = tree ? LYD_CTX(tree) : NULL;
 
-    ly_temp_log_options(&temp_lo);
+    prev_lo = ly_temp_log_options(&temp_lo);
+    if (prev_lo) {
+        /* nested call, keep the previous lo */
+        ly_temp_log_options(prev_lo);
+    }
 
     lyrc = lyd_find_path(tree, path, 0, match);
     if (lyrc == LY_EINCOMPLETE) {
@@ -1099,7 +1068,7 @@ sr_lyd_find_path(const struct lyd_node *tree, const char *path, int with_incompl
             *match = NULL;
         }
     } else if (lyrc && (lyrc != LY_ENOTFOUND)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1109,7 +1078,9 @@ sr_lyd_find_path(const struct lyd_node *tree, const char *path, int with_incompl
     }
 
 cleanup:
-    ly_temp_log_options(NULL);
+    if (!prev_lo) {
+        ly_temp_log_options(NULL);
+    }
     return err_info;
 }
 
@@ -1125,7 +1096,7 @@ sr_lyd_find_sibling_first(const struct lyd_node *sibling, const struct lyd_node
 
     lyrc = lyd_find_sibling_first(sibling, target, match);
     if (lyrc && (lyrc != LY_ENOTFOUND)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1152,7 +1123,7 @@ sr_lyd_find_sibling_val(const struct lyd_node *sibling, const struct lysc_node *
 
     lyrc = lyd_find_sibling_val(sibling, schema, value, value ? strlen(value) : 0, match);
     if (lyrc && (lyrc != LY_ENOTFOUND)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1178,7 +1149,7 @@ sr_lyd_find_sibling_opaq_next(const struct lyd_node *sibling, const char *name,
 
     lyrc = lyd_find_sibling_opaq_next(sibling, name, match);
     if (lyrc && (lyrc != LY_ENOTFOUND)) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1205,7 +1176,7 @@ sr_lyd_insert_sibling(struct lyd_node *sibling, struct lyd_node *node, struct ly
     ly_temp_log_options(&temp_lo);
 
     if (lyd_insert_sibling(sibling, node, first)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(node), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(node), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1223,7 +1194,7 @@ sr_lyd_insert_child(struct lyd_node *parent, struct lyd_node *child)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_insert_child(parent, child)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(parent), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1241,7 +1212,7 @@ sr_lyd_insert_before(struct lyd_node *sibling, struct lyd_node *node)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_insert_before(sibling, node)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(node), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(node), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1259,7 +1230,7 @@ sr_lyd_insert_after(struct lyd_node *sibling, struct lyd_node *node)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_insert_after(sibling, node)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(node), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(node), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1280,7 +1251,7 @@ sr_lyd_change_term(struct lyd_node *node, const char *value, int ignore_fail)
 
     lyrc = lyd_change_term(node, value);
     if (lyrc && (!ignore_fail || ((lyrc != LY_EEXIST) && (lyrc != LY_ENOT)))) {
-        sr_errinfo_new_ly(&err_info, ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1303,7 +1274,7 @@ sr_lyd_any_value_str(const struct lyd_node *node, char **str)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_any_value_str(node, str)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(node), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(node), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1322,7 +1293,7 @@ sr_lyd_any_copy_value(struct lyd_node *node, const union lyd_any_value *value,
     ly_temp_log_options(&temp_lo);
 
     if (lyd_any_copy_value(node, value, value_type)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(node), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(node), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1333,15 +1304,25 @@ cleanup:
 
 sr_error_info_t *
 sr_lyd_diff_siblings(const struct lyd_node *target, const struct lyd_node *source, uint32_t options,
-        struct lyd_node **diff)
+        int *snode_not_found, struct lyd_node **diff)
 {
     sr_error_info_t *err_info = NULL;
     uint32_t temp_lo = LY_LOSTORE;
+    LY_ERR lyrc;
+
+    if (snode_not_found) {
+        *snode_not_found = 0;
+    }
 
     ly_temp_log_options(&temp_lo);
 
-    if (lyd_diff_siblings(target, source, options, diff)) {
-        sr_errinfo_new_ly(&err_info, target ? LYD_CTX(target) : LYD_CTX(source), source, SR_ERR_LY);
+    lyrc = lyd_diff_siblings(target, source, options, diff);
+    if ((lyrc == LY_ENOTFOUND) && snode_not_found) {
+        /* ignore this error, just set the flag */
+        ly_err_clean(target ? LYD_CTX(target) : LYD_CTX(source), NULL);
+        *snode_not_found = 1;
+    } else if (lyrc) {
+        sr_errinfo_new_ly(&err_info, target ? LYD_CTX(target) : LYD_CTX(source), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1360,7 +1341,7 @@ sr_lyd_diff_apply_module(struct lyd_node **data, const struct lyd_node *diff, co
     ly_temp_log_options(&temp_lo);
 
     if (lyd_diff_apply_module(data, diff, mod, diff_cb, NULL)) {
-        sr_errinfo_new_ly(&err_info, mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1378,7 +1359,7 @@ sr_lyd_diff_merge_module(struct lyd_node **target, const struct lyd_node *source
     ly_temp_log_options(&temp_lo);
 
     if (lyd_diff_merge_module(target, source, mod, NULL, NULL, 0)) {
-        sr_errinfo_new_ly(&err_info, mod->ctx, NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, mod->ctx, SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1396,7 +1377,7 @@ sr_lyd_diff_merge_all(struct lyd_node **target, const struct lyd_node *source)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_diff_merge_all(target, source, 0)) {
-        sr_errinfo_new_ly(&err_info, *target ? LYD_CTX(*target) : LYD_CTX(source), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, *target ? LYD_CTX(*target) : LYD_CTX(source), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1414,7 +1395,7 @@ sr_lyd_diff_merge_tree(struct lyd_node **target_first, struct lyd_node *target_p
     ly_temp_log_options(&temp_lo);
 
     if (lyd_diff_merge_tree(target_first, target_parent, source, NULL, NULL, 0)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(*target_first), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(*target_first), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1432,7 +1413,7 @@ sr_lyd_diff_reverse_all(const struct lyd_node *diff, struct lyd_node **rdiff)
     ly_temp_log_options(&temp_lo);
 
     if (lyd_diff_reverse_all(diff, rdiff)) {
-        sr_errinfo_new_ly(&err_info, LYD_CTX(diff), NULL, SR_ERR_LY);
+        sr_errinfo_new_ly(&err_info, LYD_CTX(diff), SR_ERR_LY);
         goto cleanup;
     }
 
@@ -1541,14 +1522,18 @@ sr_ly_canonize_xpath10_value(const struct ly_ctx *ctx, const char *value, LY_VAL
     const struct lysc_node_leaf *leaf_xpath = NULL;
     struct lyd_value val = {0};
     struct ly_err_item *err = NULL;
+    struct lyplg_type *type_plg;
 
     /* get leaf of xpath1.0 type */
     leaf_xpath = (struct lysc_node_leaf *)lys_find_path(ctx, NULL, "/sysrepo:sysrepo-modules/module/rpc/path", 0);
     assert(leaf_xpath);
 
+    type_plg = lysc_get_type_plugin(leaf_xpath->type->plugin_ref);
+    assert(!strcmp(type_plg->id, "ly2 xpath1.0"));
+
     /* get the path in canonical (JSON) format */
-    if (leaf_xpath->type->plugin->store(ctx, leaf_xpath->type, value, strlen(value), 0, format, prefix_data,
-            LYD_HINT_DATA, NULL, &val, NULL, &err)) {
+    if (type_plg->store(ctx, leaf_xpath->type, value, strlen(value) * 8, 0, format, prefix_data,
+            LYD_HINT_DATA, NULL, NULL, &val, NULL, &err)) {
         if (err) {
             sr_errinfo_new(&err_info, SR_ERR_LY, "%s", err->msg);
         }
@@ -1560,7 +1545,7 @@ sr_ly_canonize_xpath10_value(const struct ly_ctx *ctx, const char *value, LY_VAL
 
 cleanup:
     ly_err_free(err);
-    leaf_xpath->type->plugin->free(ctx, &val);
+    type_plg->free(ctx, &val);
     return err_info;
 }
 
@@ -1573,7 +1558,7 @@ sr_lyd_parse_opaq_error(const struct lyd_node *node)
     ly_temp_log_options(&temp_lo);
 
     lyd_parse_opaq_error(node);
-    sr_errinfo_new_ly(&err_info, LYD_CTX(node), NULL, SR_ERR_LY);
+    sr_errinfo_new_ly(&err_info, LYD_CTX(node), SR_ERR_LY);
 
     ly_temp_log_options(NULL);
     return err_info;
@@ -1596,3 +1581,61 @@ cleanup:
     ly_temp_log_options(NULL);
     return err_info;
 }
+
+sr_error_info_t *
+sr_ly_ctx_compiled_print(const struct ly_ctx *ctx, void *mem, void **mem_end)
+{
+    sr_error_info_t *err_info = NULL;
+    uint32_t temp_lo = LY_LOSTORE;
+
+    ly_temp_log_options(&temp_lo);
+
+    if (ly_ctx_compiled_print(ctx, mem, mem_end)) {
+        sr_errinfo_new(&err_info, SR_ERR_LY, "%s", ly_last_logmsg());
+        goto cleanup;
+    }
+
+cleanup:
+    ly_temp_log_options(NULL);
+    return err_info;
+}
+
+sr_error_info_t *
+sr_ly_ctx_new_printed(const void *mem, struct ly_ctx **ctx)
+{
+    sr_error_info_t *err_info = NULL;
+    uint32_t temp_lo = LY_LOSTORE;
+
+    ly_temp_log_options(&temp_lo);
+
+    if (ly_ctx_new_printed(mem, ctx)) {
+        sr_errinfo_new(&err_info, SR_ERR_LY, "%s", ly_last_logmsg());
+        goto cleanup;
+    }
+
+cleanup:
+    ly_temp_log_options(NULL);
+    return err_info;
+}
+
+sr_error_info_t *
+sr_lyplg_ext_schema_mount_create_shared_context(struct lysc_ext_instance *ext,
+        const struct lyd_node *ext_data)
+{
+    sr_error_info_t *err_info = NULL;
+    uint32_t temp_lo = LY_LOSTORE;
+    LY_ERR r;
+
+    ly_temp_log_options(&temp_lo);
+
+    r = lyplg_ext_schema_mount_create_shared_context(ext, ext_data);
+    if (r && (r != LY_ENOT)) {
+        /* do not treat missing mount point data as an error */
+        sr_errinfo_new(&err_info, SR_ERR_LY, "%s", ly_last_logmsg());
+        goto cleanup;
+    }
+
+cleanup:
+    ly_temp_log_options(NULL);
+    return err_info;
+}
