@@ -91,18 +91,6 @@ sr_error_info_t *sr_shmsub_data_create(const char *name, const char *suffix1, in
  */
 sr_error_info_t *sr_shmsub_data_unlink(const char *name, const char *suffix1, int64_t suffix2);
 
-/**
- * @brief Collect all XPaths of specific module change subscriptions.
- *
- * @param[in] conn Connection to use.
- * @param[in] mod Mod info module to use.
- * @param[in] ds Datastore.
- * @param[out] xpaths XPaths of all the change subscriptions for @p mod.
- * @return err_info, NULL on success.
- */
-sr_error_info_t *sr_shmsub_change_notify_collect_xpaths(sr_conn_ctx_t *conn, struct sr_mod_info_mod_s *mod,
-        sr_datastore_t ds, char ***xpaths);
-
 /**
  * @brief Write into a subscriber event pipe to notify it there is a new event.
  *
@@ -173,6 +161,25 @@ sr_error_info_t *sr_shmsub_change_notify_change_done(struct sr_mod_info_s *mod_i
 sr_error_info_t *sr_shmsub_change_notify_change_abort(struct sr_mod_info_s *mod_info, const char *orig_name,
         const void *orig_data, uint32_t timeout_ms);
 
+/**
+ * @brief Collect all XPath filters of all the module change subscriptions for a module and datastore.
+ *
+ * @param[in] conn Connection to use.
+ * @param[in] shm_mod SHM mod to use.
+ * @param[in] ds Datastore to use.
+ * @param[in,out] xpaths Array of XPaths terminated by NULL to add to.
+ * @return err_info, NULL on success.
+ */
+sr_error_info_t *sr_shmsub_change_xpath_collect(sr_conn_ctx_t *conn, sr_mod_t *shm_mod, sr_datastore_t ds,
+        char ***xpaths);
+
+/**
+ * @brief Free collected XPath filters of module change subscriptions.
+ *
+ * @param[in] xpaths XPaths array to free.
+ */
+void sr_shmsub_change_xpath_free(char **xpaths);
+
 /**
  * @brief Notify about (generate) an operational get event.
  *
