@@ -250,13 +250,14 @@ srsn_filter_xpath_print_node_module(const struct lyd_node *node, const struct ly
 
         switch (opaq->format) {
         case LY_VALUE_XML:
-            /* in dict */
-            if (m->ns == opaq->name.module_ns) {
+            /* one in schema dict, other in data dict, need strcmp */
+            if (!strcmp(m->ns, opaq->name.module_ns)) {
                 return NULL;
             }
             break;
         case LY_VALUE_JSON:
-            if (m->name == opaq->name.module_name) {
+            /* one in schema dict, other in data dict, need strcmp */
+            if (!strcmp(m->name, opaq->name.module_name)) {
                 return NULL;
             }
             break;
@@ -269,7 +270,7 @@ srsn_filter_xpath_print_node_module(const struct lyd_node *node, const struct ly
         opaq = (struct lyd_node_opaq *)node;
         opaq2 = (struct lyd_node_opaq *)parent;
 
-        /* in dict */
+        /* in data dict, can compare ptrs */
         if (opaq->name.module_ns == opaq2->name.module_ns) {
             return NULL;
         }
@@ -575,7 +576,7 @@ srsn_filter_create_subtree(const struct lyd_node *node, struct srsn_filter *filt
 
                 snode = NULL;
                 while ((snode = lys_getnext(snode, NULL, mod->compiled, 0))) {
-                    if (snode->name == ((struct lyd_node_opaq *)iter)->name.name) {
+                    if (!strcmp(snode->name, ((struct lyd_node_opaq *)iter)->name.name)) {
                         /* match */
                         match = 1;
                         if ((err_info = srsn_filter_xpath_create_top(iter, mod, filter))) {
@@ -1333,7 +1334,7 @@ srsn_ntf_send_terminated(struct srsn_sub *sub, const char *reason)
 {
     sr_error_info_t *err_info = NULL;
     struct lyd_node *ly_ntf = NULL;
-    sr_conn_ctx_t *conn = NULL;
+    sr_conn_ctx_t *conn;
     const struct ly_ctx *ly_ctx;
     char buf[26];
     struct timespec ts;
@@ -1356,10 +1357,8 @@ srsn_ntf_send_terminated(struct srsn_sub *sub, const char *reason)
     }
 
 cleanup:
-    if (conn) {
-        sr_release_context(conn);
-    }
     lyd_free_tree(ly_ntf);
+    sr_release_context(conn);
     return err_info;
 }
 
