@@ -29,8 +29,10 @@
 
 #include "compat.h"
 #include "config.h"
+#include "context_change.h"
 #include "log.h"
 #include "ly_wrap.h"
+#include "shm_mod.h"
 #include "sn_common.h"
 #include "sn_yang_push.h"
 
@@ -196,14 +198,30 @@ srsn_subscribe(sr_session_ctx_t *session, const char *stream, const char *xpath_
     const struct lys_module *ly_mod;
     struct srsn_sub *s = NULL;
     struct timespec cur_ts, replay_start;
+    int valid;
 
-    if (!(ly_mod = ly_ctx_get_module_implemented(session->conn->ly_ctx, "ietf-subscribed-notifications"))) {
+    /* CONTEXT LOCK */
+    if ((err_info = sr_lycc_lock(session->conn, SR_LOCK_READ, 0, __func__))) {
+        return sr_api_ret(session, err_info);
+    }
+
+    /* find the subscribed-notifications module */
+    ly_mod = ly_ctx_get_module_implemented(sr_yang_ctx.ly_ctx, "ietf-subscribed-notifications");
+    if (!ly_mod) {
         sr_errinfo_new(&err_info, SR_ERR_UNSUPPORTED, "Module \"ietf-subscribed-notifications\" is not implemented.");
         goto cleanup;
-    } else if (start_time && lys_feature_value(ly_mod, "replay")) {
-        sr_errinfo_new(&err_info, SR_ERR_UNSUPPORTED, "Module \"ietf-subscribed-notifications\" feature \"replay\" "
-                "is not enabled.");
-        goto cleanup;
+    }
+
+    if (start_time) {
+        /* check whether the replay feature is enabled by checking if a node that depends on this feature is present */
+        if ((err_info = sr_lys_find_path(sr_yang_ctx.ly_ctx, "/ietf-subscribed-notifications:replay-completed", &valid, NULL))) {
+            goto cleanup;
+        }
+        if (!valid) {
+            sr_errinfo_new(&err_info, SR_ERR_UNSUPPORTED, "Module \"ietf-subscribed-notifications\" feature \"replay\" "
+                    "is not enabled.");
+            goto cleanup;
+        }
     }
 
     /* check parameters */
@@ -264,6 +282,9 @@ cleanup:
         srsn_sub_free(s);
     }
 
+    /* CONTEXT UNLOCK */
+    sr_lycc_unlock(session->conn, SR_LOCK_READ, 0, __func__);
+
     return sr_api_ret(session, err_info);
 }
 
@@ -273,8 +294,20 @@ srsn_yang_push_periodic(sr_session_ctx_t *session, sr_datastore_t ds, const char
 {
     sr_error_info_t *err_info = NULL;
     struct srsn_sub *s = NULL;
+    struct lys_module *ly_mod;
 
-    if (!ly_ctx_get_module_implemented(session->conn->ly_ctx, "ietf-yang-push")) {
+    /* CONTEXT LOCK */
+    if ((err_info = sr_lycc_lock(session->conn, SR_LOCK_READ, 0, __func__))) {
+        return sr_api_ret(session, err_info);
+    }
+
+    /* check whether the yang-push module is implemented, accessing context so it must be locked */
+    ly_mod = ly_ctx_get_module_implemented(sr_yang_ctx.ly_ctx, "ietf-yang-push");
+
+    /* CONTEXT UNLOCK */
+    sr_lycc_unlock(session->conn, SR_LOCK_READ, 0, __func__);
+
+    if (!ly_mod) {
         sr_errinfo_new(&err_info, SR_ERR_UNSUPPORTED, "Module \"ietf-yang-push\" is not implemented.");
         goto cleanup;
     }
@@ -331,11 +364,25 @@ srsn_yang_push_on_change(sr_session_ctx_t *session, sr_datastore_t ds, const cha
     sr_error_info_t *err_info = NULL;
     const struct lys_module *ly_mod;
     struct srsn_sub *s = NULL;
+    int valid;
 
-    if (!(ly_mod = ly_ctx_get_module_implemented(session->conn->ly_ctx, "ietf-yang-push"))) {
+    /* CONTEXT LOCK */
+    if ((err_info = sr_lycc_lock(session->conn, SR_LOCK_READ, 0, __func__))) {
+        return sr_api_ret(session, err_info);
+    }
+
+    /* find the yang-push module */
+    ly_mod = ly_ctx_get_module_implemented(sr_yang_ctx.ly_ctx, "ietf-yang-push");
+    if (!ly_mod) {
         sr_errinfo_new(&err_info, SR_ERR_UNSUPPORTED, "Module \"ietf-yang-push\" is not implemented.");
         goto cleanup;
-    } else if (lys_feature_value(ly_mod, "on-change")) {
+    }
+
+    /* check whether the on-change feature is enabled by checking if a node that depends on this feature is present */
+    if ((err_info = sr_lys_find_path(sr_yang_ctx.ly_ctx, "/ietf-yang-push:resync-subscription", &valid, NULL))) {
+        goto cleanup;
+    }
+    if (!valid) {
         sr_errinfo_new(&err_info, SR_ERR_UNSUPPORTED, "Module \"ietf-yang-push\" feature \"on-change\" is not enabled.");
         goto cleanup;
     }
@@ -391,6 +438,9 @@ cleanup:
         srsn_sub_free(s);
     }
 
+    /* CONTEXT UNLOCK */
+    sr_lycc_unlock(session->conn, SR_LOCK_READ, 0, __func__);
+
     return sr_api_ret(session, err_info);
 }
 
@@ -834,7 +884,7 @@ srsn_read_notif(int fd, const struct ly_ctx *ly_ctx, struct timespec *timestamp,
     int rc = SR_ERR_OK;
     uint32_t size;
     char *buf = NULL;
-    ssize_t r;
+    ssize_t r, rr;
 
     SR_CHECK_ARG_APIRET(!ly_ctx || !timestamp || !notif, NULL, err_info);
 
@@ -863,11 +913,27 @@ srsn_read_notif(int fd, const struct ly_ctx *ly_ctx, struct timespec *timestamp,
     buf = malloc(size + 1);
     SR_CHECK_MEM_GOTO(!buf, err_info, cleanup);
 
-    /* 3) read the notification LYB */
-    if (read(fd, buf, size) != (signed)size) {
-        sr_errinfo_new(&err_info, SR_ERR_SYS, "Failed to read a notification (%s).", strerror(errno));
-        goto cleanup;
-    }
+    /* 3) read the notification LYB, handle large notifications */
+    rr = 0;
+    do {
+        r = read(fd, buf + rr, size - rr);
+        if ((r == -1) && ((errno == EAGAIN) || (errno == EWOULDBLOCK))) {
+            /* busy */
+            usleep(100);
+            continue;
+        } else if (r == -1) {
+            /* error */
+            sr_errinfo_new(&err_info, SR_ERR_SYS, "Failed to read a notification (%s).", strerror(errno));
+            goto cleanup;
+        } else if (!r) {
+            /* end-of-file */
+            r = SR_ERR_UNSUPPORTED;
+            goto cleanup;
+        }
+
+        rr += r;
+    } while (rr < size);
+    buf[size] = '\0';
 
     /* parse the notification */
     if ((err_info = sr_lyd_parse_op(ly_ctx, buf, LYD_LYB, LYD_TYPE_NOTIF_YANG, notif))) {
