@@ -56,8 +56,11 @@ setup_f(void **state)
     st = calloc(1, sizeof *st);
     *state = st;
 
+    /* use running cache */
+    sr_cache_running(1);
+
     /* connection 1 */
-    if (sr_connect(SR_CONN_CACHE_RUNNING, &(st->conn1)) != SR_ERR_OK) {
+    if (sr_connect(0, &(st->conn1)) != SR_ERR_OK) {
         return 1;
     }
     if (sr_session_start(st->conn1, SR_DS_RUNNING, &st->sess1) != SR_ERR_OK) {
@@ -65,7 +68,7 @@ setup_f(void **state)
     }
 
     /* connection 2 */
-    if (sr_connect(SR_CONN_CACHE_RUNNING, &(st->conn2)) != SR_ERR_OK) {
+    if (sr_connect(0, &(st->conn2)) != SR_ERR_OK) {
         return 1;
     }
     if (sr_session_start(st->conn2, SR_DS_RUNNING, &st->sess2) != SR_ERR_OK) {
@@ -73,7 +76,7 @@ setup_f(void **state)
     }
 
     /* connection 3 */
-    if (sr_connect(SR_CONN_CACHE_RUNNING, &(st->conn3)) != SR_ERR_OK) {
+    if (sr_connect(0, &(st->conn3)) != SR_ERR_OK) {
         return 1;
     }
     if (sr_session_start(st->conn3, SR_DS_RUNNING, &st->sess3) != SR_ERR_OK) {
@@ -146,7 +149,7 @@ test_create1(void **state)
 
     ret = sr_get_subtree(st->sess3, "/ietf-interfaces:interfaces", 0, &subtree);
     assert_int_equal(ret, SR_ERR_OK);
-    lyd_print_mem(&str, subtree->tree, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    lyd_print_mem(&str, subtree->tree, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
     sr_release_data(subtree);
 
     const char *ptr = strstr(str, "ethS1");
@@ -412,7 +415,7 @@ test_sub_suspend(void **state)
     }
 
     /* discard all operational data */
-    ret = sr_discard_oper_changes(NULL, st->sess2, NULL, 0);
+    ret = sr_discard_oper_changes(st->sess2, NULL, 0);
     assert_int_equal(ret, SR_ERR_OK);
 
     ret = sr_session_switch_ds(st->sess2, SR_DS_RUNNING);
@@ -462,7 +465,7 @@ slow_oper_cb(sr_session_ctx_t *session, uint32_t sub_id, const char *module_name
     (void)private_data;
 
     /* Wait longer than run cache lock timeout */
-    usleep(1000 * (1 + SR_CONN_RUN_CACHE_LOCK_TIMEOUT));
+    usleep(1000 * (1 + SR_RUN_CACHE_LOCK_TIMEOUT));
 
     return SR_ERR_OK;
 }
@@ -521,10 +524,105 @@ test_run_change_oper_get(void **state)
     pthread_barrier_destroy(&st->barrier);
 }
 
+/* TEST */
+static void *
+test_cache_user(void *state)
+{
+    struct state *st = (struct state *)state;
+    sr_conn_ctx_t *conn;
+    sr_session_ctx_t *sess;
+    int i = 0, ret;
+    static ATOMIC_T thread_id = 0;
+    char xpath[32] = "";
+
+    snprintf(xpath, sizeof(xpath), "/test:l1[k='key%lu']/v", ATOMIC_INC_RELAXED(thread_id));
+
+    ret = sr_connect(0, &conn);
+    assert_int_equal(ret, SR_ERR_OK);
+
+    /* enable the running cache, all other caches are always enabled */
+    sr_cache_running(1);
+
+    ret = sr_session_start(conn, SR_DS_OPERATIONAL, &sess);
+    assert_int_equal(ret, SR_ERR_OK);
+
+    /* signal parent that we are ready */
+    pthread_barrier_wait(&st->barrier);
+
+    for (i = 0; i < 100; i++) {
+        sched_yield();
+        ret = sr_set_item_str(sess, xpath, "1", NULL, 0);
+        assert_int_equal(ret, SR_ERR_OK);
+
+        ret = sr_apply_changes(sess, 0);
+        assert_int_equal(ret, SR_ERR_OK);
+
+        sched_yield();
+
+        if (i % 2) {
+            ret = sr_discard_oper_changes(sess, NULL, 0);
+        } else {
+            ret = sr_delete_item(sess, xpath, 0);
+            assert_int_equal(ret, SR_ERR_OK);
+            ret = sr_apply_changes(sess, 0);
+        }
+        assert_int_equal(ret, SR_ERR_OK);
+
+        ret = sr_session_switch_ds(sess,  (i % 2) ? SR_DS_RUNNING : SR_DS_OPERATIONAL);
+        assert_int_equal(ret, SR_ERR_OK);
+    }
+
+    sr_disconnect(conn);
+
+    return NULL;
+}
+
+static void
+test_ctx_change_with_cache(void **state)
+{
+    struct state *st = (struct state *)*state;
+    const int thread_count = 3;
+    int i, ret = 0;
+    pthread_t tid[thread_count];
+    const char *module_names[] = {
+        "ietf-interfaces",
+        NULL
+    };
+    const char *schema_paths[] = {
+        TESTS_SRC_DIR "/files/ietf-interfaces.yang",
+        NULL
+    };
+
+    pthread_barrier_init(&st->barrier, NULL, thread_count + 1);
+
+    for (i = 0; i < thread_count; ++i) {
+        pthread_create(&tid[i], NULL, test_cache_user, st);
+    }
+
+    /* wait for threads to connect to sysrepo */
+    pthread_barrier_wait(&st->barrier);
+
+    /* change the context many times */
+    for (i = 0; i < 10; i++) {
+        ret = sr_remove_modules(st->conn1, module_names, 0);
+        assert_int_equal(ret, SR_ERR_OK);
+
+        ret = sr_install_modules(st->conn1, schema_paths, TESTS_SRC_DIR "/files", NULL);
+        assert_int_equal(ret, SR_ERR_OK);
+    }
+
+    for (i = 0; i < thread_count; ++i) {
+        pthread_join(tid[i], NULL);
+    }
+
+    pthread_barrier_destroy(&st->barrier);
+}
+
 int
 main(void)
 {
     const struct CMUnitTest tests[] = {
+        cmocka_unit_test_teardown(test_ctx_change_with_cache, clear_interfaces),
         cmocka_unit_test_teardown(test_create1, clear_interfaces),
         cmocka_unit_test(test_new_conn),
         cmocka_unit_test_teardown(test_sub_suspend, clear_interfaces),
