@@ -298,7 +298,7 @@ test_replay(void **state)
     int ret, fd;
     char *str, *exp;
     uint32_t sub_id;
-    struct timespec ts;
+    struct timespec ts, replay_start_time;
 
     /* remember realtime before the notification */
     clock_gettime(CLOCK_REALTIME, &ts);
@@ -308,7 +308,7 @@ test_replay(void **state)
     assert_int_equal(SR_ERR_OK, sr_notif_send(st->sess, "/ops:notif4", NULL, 0, 0, 0));
 
     /* subscribe to notifs with start-time */
-    assert_int_equal(SR_ERR_OK, srsn_subscribe(st->sess, "NETCONF", NULL, NULL, &ts, 0, NULL, NULL, &fd, &sub_id));
+    assert_int_equal(SR_ERR_OK, srsn_subscribe(st->sess, "NETCONF", NULL, NULL, &ts, 0, NULL, &replay_start_time, &fd, &sub_id));
 
     /* read and check the notifs */
     assert_int_equal(SR_ERR_OK, srsn_poll(fd, 1000));
@@ -318,6 +318,80 @@ test_replay(void **state)
     free(str);
     lyd_free_tree(notif);
 
+    /* check that replay start time is set to the time of the first notification in the replay buffer */
+    assert_int_equal(replay_start_time.tv_sec, ts.tv_sec);
+
+    assert_int_equal(SR_ERR_OK, srsn_poll(fd, 1000));
+    assert_int_equal(SR_ERR_OK, srsn_read_notif(fd, st->ly_ctx, &ts, &notif));
+    lyd_print_mem(&str, notif, LYD_XML, 0);
+    ret = asprintf(&exp,
+            "<replay-completed xmlns=\"urn:ietf:params:xml:ns:yang:ietf-subscribed-notifications\">\n"
+            "  <id>%" PRIu32 "</id>\n"
+            "</replay-completed>\n", sub_id);
+    assert_int_not_equal(ret, -1);
+    assert_string_equal(str, exp);
+    free(str);
+    free(exp);
+    lyd_free_tree(notif);
+
+    /* stop the subscription */
+    assert_int_equal(SR_ERR_OK, srsn_terminate(sub_id, "ietf-subscribed-notifications:no-such-subscription"));
+
+    /* read (no poll, pipe closed) and check the notif */
+    assert_int_equal(SR_ERR_OK, srsn_read_notif(fd, st->ly_ctx, &ts, &notif));
+    lyd_print_mem(&str, notif, LYD_XML, 0);
+    ret = asprintf(&exp,
+            "<subscription-terminated xmlns=\"urn:ietf:params:xml:ns:yang:ietf-subscribed-notifications\">\n"
+            "  <id>%" PRIu32 "</id>\n"
+            "  <reason>no-such-subscription</reason>\n"
+            "</subscription-terminated>\n", sub_id);
+    assert_int_not_equal(ret, -1);
+    assert_string_equal(str, exp);
+    free(str);
+    free(exp);
+    lyd_free_tree(notif);
+
+    /* cleanup */
+    close(fd);
+}
+
+/* TEST */
+static void
+test_replay_start_time(void **state)
+{
+    struct state *st = (struct state *)*state;
+    struct lyd_node *notif;
+    int ret, fd;
+    char *str, *exp;
+    uint32_t sub_id;
+    struct timespec ts, replay_start_time;
+
+    /* store a notification not supposed to be replayed */
+    assert_int_equal(SR_ERR_OK, sr_set_module_replay_support(st->conn, "ops", 1));
+    assert_int_equal(SR_ERR_OK, sr_notif_send(st->sess, "/ops:notif4", NULL, 0, 0, 0));
+
+    /* remember realtime after the notification */
+    clock_gettime(CLOCK_REALTIME, &ts);
+
+    /* store a notification for replay */
+    assert_int_equal(SR_ERR_OK, sr_set_module_replay_support(st->conn, "test", 1));
+    assert_int_equal(SR_ERR_OK, sr_notif_send(st->sess, "/test:notif1", NULL, 0, 0, 0));
+
+    /* subscribe to notifs with start-time */
+    assert_int_equal(SR_ERR_OK, srsn_subscribe(st->sess, "NETCONF", NULL, NULL, &ts, 0, NULL, &replay_start_time, &fd, &sub_id));
+
+    /* there are notifs from time earlier than the start time */
+    assert_int_equal(replay_start_time.tv_sec, 0);
+
+    /* read replayed notification */
+    assert_int_equal(SR_ERR_OK, srsn_poll(fd, 1000));
+    assert_int_equal(SR_ERR_OK, srsn_read_notif(fd, st->ly_ctx, &ts, &notif));
+    lyd_print_mem(&str, notif, LYD_XML, 0);
+    assert_string_equal(str, "<notif1 xmlns=\"urn:test\"/>\n");
+    free(str);
+    lyd_free_tree(notif);
+
+    /* replay completed */
     assert_int_equal(SR_ERR_OK, srsn_poll(fd, 1000));
     assert_int_equal(SR_ERR_OK, srsn_read_notif(fd, st->ly_ctx, &ts, &notif));
     lyd_print_mem(&str, notif, LYD_XML, 0);
@@ -373,12 +447,15 @@ test_suspend(void **state)
     assert_int_equal(SR_ERR_OK, srsn_poll(fd, 500));
     assert_int_equal(SR_ERR_OK, srsn_read_notif(fd, st->ly_ctx, &ts, &notif));
     lyd_print_mem(&str, notif, LYD_XML, 0);
-    assert_string_equal(str,
+    ret = asprintf(&exp,
             "<subscription-suspended xmlns=\"urn:ietf:params:xml:ns:yang:ietf-subscribed-notifications\">\n"
-            "  <id>5</id>\n"
+            "  <id>%" PRIu32 "</id>\n"
             "  <reason>insufficient-resources</reason>\n"
-            "</subscription-suspended>\n");
+            "</subscription-suspended>\n", sub_id);
+    assert_int_not_equal(ret, -1);
+    assert_string_equal(str, exp);
     free(str);
+    free(exp);
     lyd_free_tree(notif);
 
     /* send a notif */
@@ -395,11 +472,14 @@ test_suspend(void **state)
     assert_int_equal(SR_ERR_OK, srsn_poll(fd, 500));
     assert_int_equal(SR_ERR_OK, srsn_read_notif(fd, st->ly_ctx, &ts, &notif));
     lyd_print_mem(&str, notif, LYD_XML, 0);
-    assert_string_equal(str,
+    ret = asprintf(&exp,
             "<subscription-resumed xmlns=\"urn:ietf:params:xml:ns:yang:ietf-subscribed-notifications\">\n"
-            "  <id>5</id>\n"
-            "</subscription-resumed>\n");
+            "  <id>%" PRIu32 "</id>\n"
+            "</subscription-resumed>\n", sub_id);
+    assert_int_not_equal(ret, -1);
+    assert_string_equal(str, exp);
     free(str);
+    free(exp);
     lyd_free_tree(notif);
 
     /* stop the subscription */
@@ -880,6 +960,7 @@ main(void)
         cmocka_unit_test(test_sub_delete),
         cmocka_unit_test(test_stop_time),
         cmocka_unit_test(test_replay),
+        cmocka_unit_test(test_replay_start_time),
         cmocka_unit_test(test_suspend),
         cmocka_unit_test(test_yp_periodic),
         cmocka_unit_test(test_yp_on_change),
